@@ -4,26 +4,19 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KPKPASS_BOARDINGPASS_H
-#define KPKPASS_BOARDINGPASS_H
+#pragma once
 
 #include "pass.h"
 
-namespace KPkPass {
-
+namespace KPkPass
+{
 /** Boarding pass */
 class KPKPASS_EXPORT BoardingPass : public Pass
 {
     Q_OBJECT
     Q_PROPERTY(TransitType transitType READ transitType CONSTANT)
 public:
-    enum TransitType {
-        Air,
-        Boat,
-        Bus,
-        Train,
-        Generic
-    };
+    enum TransitType { Air, Boat, Bus, Train, Generic };
     Q_ENUM(TransitType)
 
     explicit BoardingPass(QObject *parent = nullptr);
@@ -34,4 +27,3 @@ public:
 
 }
 
-#endif // KPKPASS_BOARDINGPASS_H
